==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/OperationArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.OperationArgument;
import io.ciera.tool.sql.ooaofooa.message.OperationArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.MessageArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.OperationParameterSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.OperationParameterSetImpl;

import java.util.Arrays;
import java.util.List;


public class OperationArgumentSetImpl extends InstanceSet<OperationArgumentSet,OperationArgument> implements OperationArgumentSet {

    // attributes
    @Override
    public void setArg_ID( UniqueId ref_Arg_ID ) throws XtumlException {
        for ( OperationArgument operationargument : this ) operationargument.setArg_ID( ref_Arg_ID );
    }
    @Override
    public void setTParm_ID( UniqueId ref_TParm_ID ) throws XtumlException {
        for ( OperationArgument operationargument : this ) operationargument.setTParm_ID( ref_TParm_ID );
    }


    // selections
    @Override
    public MessageArgumentSet R1013_is_a_MessageArgument() throws XtumlException {
        MessageArgumentSet messageargumentset = new MessageArgumentSetImpl();
        for ( OperationArgument operationargument : this ) messageargumentset.add( operationargument.R1013_is_a_MessageArgument() );
        return messageargumentset;
    }
    @Override
    public OperationParameterSet R1015_is_represented_by_OperationParameter() throws XtumlException {
        OperationParameterSet operationparameterset = new OperationParameterSetImpl();
        for ( OperationArgument operationargument : this ) operationparameterset.add( operationargument.R1015_is_represented_by_OperationParameter() );
        return operationparameterset;
    }


    @Override
    public OperationArgument nullElement() {
        return OperationArgumentImpl.EMPTY_OPERATIONARGUMENT;
    }

    @Override
    public OperationArgumentSet emptySet() {
      return new OperationArgumentSetImpl();
    }

    @Override
    public OperationArgumentSet value() {
        return this;
    }

    @Override
    public List<OperationArgument> elements() {
        return Arrays.asList(toArray(new OperationArgument[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/OperationArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.OperationArgument;
import io.ciera.tool.sql.ooaofooa.message.OperationArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.MessageArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.OperationParameterSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.OperationParameterSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class OperationArgumentSetImpl extends InstanceSet<OperationArgumentSet,OperationArgument> implements OperationArgumentSet {

    public OperationArgumentSetImpl() {
    }

    public OperationArgumentSetImpl(Comparator<? super OperationArgument> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setTParm_ID( UniqueId ref_TParm_ID ) throws XtumlException {
        for ( OperationArgument operationargument : this ) operationargument.setTParm_ID( ref_TParm_ID );
    }
    @Override
    public void setArg_ID( UniqueId ref_Arg_ID ) throws XtumlException {
        for ( OperationArgument operationargument : this ) operationargument.setArg_ID( ref_Arg_ID );
    }


    // selections
    @Override
    public MessageArgumentSet R1013_is_a_MessageArgument() throws XtumlException {
        MessageArgumentSet messageargumentset = new MessageArgumentSetImpl();
        for ( OperationArgument operationargument : this ) messageargumentset.add( operationargument.R1013_is_a_MessageArgument() );
        return messageargumentset;
    }
    @Override
    public OperationParameterSet R1015_is_represented_by_OperationParameter() throws XtumlException {
        OperationParameterSet operationparameterset = new OperationParameterSetImpl();
        for ( OperationArgument operationargument : this ) operationparameterset.add( operationargument.R1015_is_represented_by_OperationParameter() );
        return operationparameterset;
    }


    @Override
    public OperationArgument nullElement() {
        return OperationArgumentImpl.EMPTY_OPERATIONARGUMENT;
    }

    @Override
    public OperationArgumentSet emptySet() {
      return new OperationArgumentSetImpl();
    }

    @Override
    public OperationArgumentSet emptySet(Comparator<? super OperationArgument> comp) {
      return new OperationArgumentSetImpl(comp);
    }

    @Override
    public OperationArgumentSet value() {
        return this;
    }

    @Override
    public List<OperationArgument> elements() {
        return Arrays.asList(toArray(new OperationArgument[0]));
    }

}
